@@ -41,7 +41,7 @@ SOFTWARE.
 #endif
 #if HAVE_GNUMALLOC_H
 #include <gnumalloc.h>
-#elif HAVE_MALLOC_H && !defined(_SQUID_FREEBSD_) && !defined(_SQUID_NEXT_)
+#elif HAVE_MALLOC_H
 #include <malloc.h>
 #endif
 #if HAVE_MEMORY_H
@@ -124,7 +124,7 @@ int Line = 1;
 #define COUNTER	    9
 #define GAUGE	    10
 #define TIMETICKS   11
-#define OPAQUE	    12
+#define SNMP_OPAQUE	    12
 #define NUL	    13
 #define SEQUENCE    14
 #define OF	    15		/* SEQUENCE OF */
@@ -135,9 +135,9 @@ int Line = 1;
 #define	WRITEONLY   20
 #undef NOACCESS
 #define NOACCESS    21
-#define STATUS	    22
+#define SNMP_STATUS 22
 #define MANDATORY   23
-#define OPTIONAL    24
+#define SNMP_OPTIONAL    24
 #define OBSOLETE    25
 #define RECOMMENDED 26
 #define PUNCT	    27
@@ -165,9 +165,9 @@ struct tok {
 struct tok tokens[] =
 {
     {"obsolete", sizeof("obsolete") - 1, OBSOLETE},
-    {"Opaque", sizeof("Opaque") - 1, OPAQUE},
+    {"Opaque", sizeof("Opaque") - 1, SNMP_OPAQUE},
     {"recommended", sizeof("recommended") - 1, RECOMMENDED},
-    {"optional", sizeof("optional") - 1, OPTIONAL},
+    {"optional", sizeof("optional") - 1, SNMP_OPTIONAL},
     {"mandatory", sizeof("mandatory") - 1, MANDATORY},
     {"current", sizeof("current") - 1, MANDATORY},
     {"not-accessible", sizeof("not-accessible") - 1, NOACCESS},
@@ -193,7 +193,7 @@ struct tok tokens[] =
     {"read-only", sizeof("read-only") - 1, READONLY},
     {"ACCESS", sizeof("ACCESS") - 1, ACCESS},
     {"MAX-ACCESS", sizeof("MAX-ACCESS") - 1, ACCESS},
-    {"STATUS", sizeof("STATUS") - 1, STATUS},
+    {"STATUS", sizeof("STATUS") - 1, SNMP_STATUS},
     {"SYNTAX", sizeof("SYNTAX") - 1, SYNTAX},
     {"OBJECT-TYPE", sizeof("OBJECT-TYPE") - 1, OBJTYPE},
     {"{", sizeof("{") - 1, LEFTBRACKET},
@@ -328,7 +328,7 @@ build_translation_table(void)
 	case TIMETICKS:
 	    translation_table[count] = TYPE_TIMETICKS;
 	    break;
-	case OPAQUE:
+	case SNMP_OPAQUE:
 	    translation_table[count] = TYPE_OPAQUE;
 	    break;
 	case NUL:
@@ -488,9 +488,9 @@ get_token(register FILE *fp, register char *token)
     register struct tok *tp;
 
     *cp = 0;
-    ch = last;
+    ch = (unsigned char)last;
     /* skip all white space */
-    while (isspace(ch) && ch != -1) {
+    while (xisspace(ch) && ch != -1) {
 	ch = getc(fp);
 	if (ch == '\n')
 	    Line++;
@@ -506,10 +506,10 @@ get_token(register FILE *fp, register char *token)
     do {
 	if (ch == '\n')
 	    Line++;
-	if (isspace(ch) || ch == '(' || ch == ')' ||
+	if (xisspace(ch) || ch == '(' || ch == ')' ||
 	    ch == '{' || ch == '}' || ch == ',' ||
 	    ch == '"') {
-	    if (!isspace(ch) && *token == 0) {
+	    if (!xisspace(ch) && *token == 0) {
 		hash += ch;
 		*cp++ = ch;
 		last = ' ';
@@ -540,7 +540,7 @@ get_token(register FILE *fp, register char *token)
 		return get_token(fp, token);
 	    }
 	    for (cp = token; *cp; cp++)
-		if (!isdigit(*cp))
+		if (!xisdigit(*cp))
 		    return LABEL;
 	    return NUMBER;
 	} else {
@@ -844,7 +844,7 @@ parse_objecttype(register FILE *fp, char *name)
     case COUNTER:
     case GAUGE:
     case TIMETICKS:
-    case OPAQUE:
+    case SNMP_OPAQUE:
     case NUL:
     case LABEL:
 	strcpy(syntax, token);
@@ -867,13 +867,13 @@ parse_objecttype(register FILE *fp, char *name)
 	return 0;
     }
     type = get_token(fp, token);
-    if (type != STATUS) {
+    if (type != SNMP_STATUS) {
 	print_error("Should be STATUS", token, nexttype);
 	free_node(np);
 	return 0;
     }
     type = get_token(fp, token);
-    if (type != MANDATORY && type != OPTIONAL && type != OBSOLETE && type != RECOMMENDED) {
+    if (type != MANDATORY && type != SNMP_OPTIONAL && type != OBSOLETE && type != RECOMMENDED) {
 	print_error("Bad status", token, type);
 	free_node(np);
 	return 0;
